import React, { Component } from 'react';
import { TextField, Typography } from '@material-ui/core';
import { DateTimePicker, KeyboardDatePicker, DatePicker } from "@material-ui/pickers";
import MenuItem from '@material-ui/core/MenuItem';
import * as R from 'ramda'
import format from "date-fns/format";
import api from "../../api";
import Autocomplete from '@material-ui/lab/Autocomplete';

const type = [
    {
      value: '1',
      label: 'YEARLY',
    },
    {
      value: '2',
      label: 'MONTHLY',
    },
    {
      value: '3',
      label: 'DAILY',
    },
  ];
const approve_by = [
  {
    user_id: '1',
    fullname: 'John Doe',
  },
  {
    user_id: '2',
    fullname: 'John Doe lagi',
  },
];
const operator = [
  {
    value: '1',
    label: '-',
  },
  {
    value: '2',
    label: 'AND',
  },
  {
    value: '3',
    label: 'OR',
  },
];

export default class CreateApprovalMatrix extends Component {
    constructor(props) {
        super(props)
        this.state = {
            userId: null,
            // type: '',
            order: '',
            approvedBy: null,
            // operator: '',
            startDate: '',
            endDate: '',
            userData: [],
            value: null

        }
    }

    componentDidMount() {
        this.getUserData()
    }

    getUserData() {
        api.create().getApprovedByAM().then((response) => {
            if (response.data.status == 'success') {
                let data = response.data.data
                let userData = data.map((item) => {
                    return {
                        user_id: item.user_id,
                        fullname: item.fullname
                    }
                })
                // console.log(userData)
                let defaultProps = {
                    options: userData,
                    getOptionLabel: (option) => option.fullname,
                  };
                this.setState({ approvedBy: defaultProps, userData: response.data.data, value: userData[0] })
            } else {
                alert(response.data.message)
            }
        })
    }
    

    handleChange(e, type) {
        let data = this.state
        let isDate = type !== '' ? true : false
        if (isDate && type == 'start_date') {
            this.setState({ startDate: format(e, 'yyyy-MM-dd') }, () => {
                // console.log(this.state.startDate)
            })
        } else if (isDate && type == 'end_date') {
            this.setState({ endDate: format(e, 'yyyy-MM-dd') }, () => {
                // console.log(this.state.endDate)
            })
        } else {
            // this.setState({...data, tempData: {...this.state.tempData, [e.target.name] :  e.target.value}})
        }

    }

    validasi() {
        if (R.isEmpty(this.state.order)) return alert("Order is Required.");
        if (!R.isEmpty(this.state.startDate) && !R.isEmpty(this.state.endDate) && (this.state.startDate > this.state.endDate)) return alert("Masa Berlaku Tidak Boleh Kurang Dari Tanggal Mulai");
        if (R.isEmpty(this.state.startDate)) return alert("Tanggal Mulai is Required.");
        if (R.isEmpty(this.state.endDate)) return alert("Tanggal Berakhir is Required.");
        console.log('masuk');
        let payload = {
            "approval_type_id": 2,
            "orders": this.state.order,
            "user_id": this.state.userId,
            "operator_type_id": 2,
            "start_date": this.state.startDate,
            "end_date": this.state.endDate
        }
        this.props.createAM(payload)
        // console.log(payload)

    }

    render() {
        return (
            <div className="test app-popup-show" style={{ paddingTop: 100 }}>
                <div className="popup-content background-white border-radius" style={{ borderRadius: 8 }}>
                    <div className="popup-panel grid grid-2x" style={{ backgroundColor: '#51c6ea', height: 64, borderTopRightRadius: 8, borderTopLeftRadius: 8 }}>
                        <div className="col-1" style={{ maxWidth: "inherit", display: 'flex', alignItems: 'center' }}>
                            <div className="popup-title">
                                <span style={{ color: '#fff', fontSize: 16, fontWeight: 'bold' }}>Tambah Data</span>
                            </div>
                        </div>
                        <div className="col-2 content-right" style={{ maxWidth: "inherit", alignSelf: 'center' }}>
                            <button
                                type="button"
                                className="btn btn-circle btn-white"
                                onClick={() => this.props.onClickClose()}
                            >
                                <i className="fa fa-lg fa-times" style={{ color: 'white' }} />
                            </button>
                        </div>
                    </div>

                    <div className="border-bottom" style={{ padding: 20 }}>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-bottom-20px">
                                    <TextField
                                        style={{ width: '100%', height: '90%' }}
                                        id="id"
                                        variant="filled"
                                        label="ID"
                                        disabled
                                        // value={this.state.periode}
                                    >
                                        {/* {periode.map((option) => (
                                            <MenuItem key={option.value} value={option.value}>
                                                {option.label}
                                            </MenuItem>
                                        ))} */}
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-bottom-20px" style={{ marginTop: 8 }}>
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="type"
                                        select
                                        label="Tipe Persetujuan"
                                        value={this.state.type}
                                        onChange={(e) => null}
                                    >
                                        {type.map((option) => (
                                            <MenuItem key={option.value} value={option.value}>
                                                {option.label}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-bottom-20px">
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="order"
                                        label="Order"
                                        value={this.state.order}
                                        onChange={(e) => this.setState({ order: e.target.value })}
                                    >
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-bottom-20px">
                                <Autocomplete
                                    {...this.state.approvedBy}
                                    id="debug"
                                    onChange={(event, newInputValue) => this.setState({userId:newInputValue.user_id}, () => console.log(this.state.userId))}
                                    debug
                                    renderInput={(params) => <TextField {...params} label="debug" margin="normal" />}
                                    value={this.state.value}
                                />
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-bottom-20px">
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="operator"
                                        select
                                        label="Operator"
                                        value={this.state.operator}
                                        onChange={(e) => null}
                                    >
                                        {operator.map((option) => (
                                            <MenuItem key={option.value} value={option.value}>
                                                {option.label}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-bottom-20px">
                                <DatePicker
                                    margin="normal"
                                    id="startDate"
                                    label="Berlaku Mulai"
                                    format="dd MMMM yyyy"
                                    value={this.state.startDate == "" ? null : this.state.startDate}
                                    onChange={(e) => this.handleChange(e, 'start_date')}
                                    KeyboardButtonProps={{
                                        'aria-label': 'change date',
                                    }}

                                    style={{ padding: 0, margin: 0, width: '100%' }}
                                />
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-bottom-20px">
                                <DatePicker
                                    margin="normal"
                                    id="endDate"
                                    label="Berlaku Hingga"
                                    format="dd MMMM yyyy"
                                    value={this.state.endDate == "" ? null : this.state.endDate}
                                    onChange={(e) => this.handleChange(e, 'end_date')}
                                    KeyboardButtonProps={{
                                        'aria-label': 'change date',
                                    }}
                                    style={{ padding: 0, margin: 0, width: '100%' }}
                                />
                                </div>
                            </div>
                        </div>
                        <div className="grid grid-2x grid-mobile-none gap-15px">
                            <div className="column-1">
                                <div className="margin-bottom-20px">
                                    <TextField
                                        style={{ width: '100%' }}
                                        variant="filled"
                                        id="status"
                                        label="Status"
                                        disabled
                                        defaultValue={"Aktif"}
                                    >
                                    </TextField>
                                </div>
                            </div>
                            <div className="column-2">
                                <div className="margin-bottom-20px" style={{ marginTop: 8 }}>
                                    <TextField
                                        style={{ width: '100%' }}
                                        id="max-value"
                                        label="Max Value"
                                        // value={this.state.periode}
                                    >
                                    </TextField>
                                </div>
                            </div>
                        </div>
                        <div className="">
                            <span style={{ fontSize: 11, fontWeight: 600 }}>Dibuat<span style={{ marginLeft: 20}}> : Admin - 21 Jul 2020, 18:45</span></span>
                        </div>
                        <div className="">
                            <span style={{ fontSize: 11, fontWeight: 'bold' }}>Diubah<span style={{ marginLeft: 17}}> : Admin - 21 Jul 2020, 18:45</span></span>
                        </div>
                    </div>
                    <div className="border-top grid grid-2x" style={{ height: 56, backgroundColor: '#f5f5f5', paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1" style={{ alignSelf: 'center' }}>
                            <div onClick={() => this.props.onClickClose()} style={{ width: 102, height: 30, border: 'solid 1px #354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center', cursor:"pointer" }}>
                                <span style={{ color: '#354960', fontSize: 11 }} >Batal</span>
                            </div>
                        </div>
                        <div className="column-2" style={{display: 'flex', justifyContent: 'flex-end', alignItems: 'center'}}>
                            <div onClick={() => this.validasi()} style={{ width: 102, height: 30, backgroundColor: '#354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center', cursor:"pointer" }}>
                                <span style={{ color: '#fff', fontSize: 11 }}>Simpan</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}
